<?php
/**
 * Main plugin file.
 * Finally, use widgets to maintain & customize your Archive Page Template in Genesis Framework and Child Themes
 * to create archive or sitemap listings.
 *
 * @package   Genesis Widgetized Archive
 * @author    David Decker
 * @link      http://twitter.com/deckerweb
 * @copyright Copyright 2012, David Decker - DECKERWEB
 *
 * Plugin Name: Genesis Widgetized Archive
 * Plugin URI: http://genesisthemes.de/en/wp-plugins/genesis-widgetized-archive/
 * Description: Finally, use widgets to maintain & customize your Archive Page Template in Genesis Framework and Child Themes to create archive or sitemap listings.
 * Version: 1.0.0
 * Author: David Decker - DECKERWEB
 * Author URI: http://deckerweb.de/
 * License: GPLv2 or later
 * License URI: http://www.opensource.org/licenses/gpl-license.php
 * Text Domain: genesis-widgetized-archive
 * Domain Path: /languages/
 *
 * Copyright 2012 David Decker - DECKERWEB
 *
 *     This file is part of Genesis Widgetized Archive,
 *     a plugin for WordPress.
 *
 *     Genesis Widgetized Archive is free software:
 *     You can redistribute it and/or modify it under the terms of the
 *     GNU General Public License as published by the Free Software
 *     Foundation, either version 2 of the License, or (at your option)
 *     any later version.
 *
 *     Genesis Widgetized Archive is distributed in the hope that
 *     it will be useful, but WITHOUT ANY WARRANTY; without even the
 *     implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 *     PURPOSE. See the GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with WordPress. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Setting constants
 *
 * @since 1.0.0
 */
/** Set plugin version */
define( 'GWAT_VERSION', ddw_gwat_plugin_get_data( 'Version' ) );

/** Plugin directory */
define( 'GWAT_PLUGIN_DIR', dirname( __FILE__ ) );

/** Plugin base directory */
define( 'GWAT_PLUGIN_BASEDIR', dirname( plugin_basename( __FILE__ ) ) );

/** Set constant/ filter for WordPress languages directory */
$gwat_wp_lang_dir = GWAT_PLUGIN_BASEDIR . '/../../languages/genesis-widgetized-archive/';
define( 'GWAT_WP_LANG_DIR', apply_filters( 'gwat_filter_wp_lang_dir', $gwat_wp_lang_dir ) );

/** Set constant/ filter for plugin's languages directory */
$gwat_lang_dir = GWAT_PLUGIN_BASEDIR . '/languages/';
define( 'GWAT_LANG_DIR', apply_filters( 'gwat_filter_lang_dir', $gwat_lang_dir ) );


register_activation_hook( __FILE__, 'ddw_gwat_activation_check' );
/**
 * Checks for activated Genesis Framework before allowing plugin to activate
 *
 * @since 1.0.0
 */
function ddw_gwat_activation_check() {

	/**
	 * Look for translations to display for the activation message
	 * Look first in WordPress "languages" folder, then in plugin's "languages" folder
	 */
	load_plugin_textdomain( 'genesis-widgetized-archive', false, GWAT_WP_LANG_DIR );
	load_plugin_textdomain( 'genesis-widgetized-archive', false, GWAT_LANG_DIR );

	/** Check for activated Genesis Framework (= template/parent theme) */
	if ( basename( get_template_directory() ) != 'genesis' ) {

		/** If no Genesis, deactivate ourself */
		deactivate_plugins( plugin_basename( __FILE__ ) );

		/** Deactivation message */
		wp_die( sprintf( __( 'Sorry, you can&rsquo;t activate unless you have installed the %1$sGenesis Framework%2$s', 'genesis-widgetized-archive' ), '<a href="http://deckerweb.de/go/genesis/" target="_new">', '</a>' ) );

	}  // end-if Genesis check

}  // end of function ddw_gwat_activation_check


add_action( 'init', 'ddw_gwat_init', 1 );
/**
 * Load the text domain for translation of the plugin.
 * 
 * @since 1.0.0
 */
function ddw_gwat_init() {

	/** First look in WordPress' "languages" folder = custom & update-secure! */
	load_plugin_textdomain( 'genesis-widgetized-archive', false, GWAT_WP_LANG_DIR );

	/** Then look in plugin's "languages" folder = default */
	load_plugin_textdomain( 'genesis-widgetized-archive', false, GWAT_LANG_DIR );

}  // end of function ddw_gwat_init


add_action( 'init', 'ddw_gwat_setup' );
/**
 * Setup: Register Widget Areas (Note: Has to be early on the "init" hook in order to display translations!)
 *
 * @since 1.0.0
 */
function ddw_gwat_setup() {

	/** Define constants and set defaults for removing all or certain sections */
	if ( ! defined( 'GWAT_NO_SECOND_WIDGET_AREA' ) ) {
		define( 'GWAT_NO_SECOND_WIDGET_AREA', FALSE );
	}

	if ( ! defined( 'GWAT_NO_THIRD_WIDGET_AREA' ) ) {
		define( 'GWAT_NO_THIRD_WIDGET_AREA', FALSE );
	}

	if ( ! defined( 'GWAT_NO_WIDGETS_SHORTCODE' ) ) {
		define( 'GWAT_NO_WIDGETS_SHORTCODE', FALSE );
	}

	/** Load the admin and frontend functions only when needed */
	if ( is_admin() ) {
		require_once( GWAT_PLUGIN_DIR . '/includes/gwat-admin.php' );
	} else {
		require_once( GWAT_PLUGIN_DIR . '/includes/gwat-frontend.php' );
	}

	/** Add "Widgets Page" link to plugin page */
	if ( is_admin() && current_user_can( 'edit_theme_options' ) ) {
		add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ) , 'ddw_gwat_widgets_page_link' );
	}

	/** Check for activated Genesis Framework (= template/parent theme) */
	if ( basename( get_template_directory() ) == 'genesis' ) {

		/** Add shortcode support to widgets */
		if ( ! GWAT_NO_WIDGETS_SHORTCODE ) {
			add_filter( 'widget_text', 'do_shortcode' );
		}  // end-if constant check

		/** Set filter for "Archive Page Template #1" widget title */
		$gwat_archive_one_widget_title = apply_filters( 'gwat_filter_archive_one_widget_title', __( 'Archive Page Template #1', 'genesis-widgetized-archive' ) );

		/** Set filter for "Archive Page Template #1" widget description */
		$gwat_archive_one_widget_description = apply_filters( 'gwat_filter_archive_one_widget_description', __( 'This is the first widget area for the Archive Page Template (bundled with the Genesis Framework).', 'genesis-widgetized-archive' ) );

		/** Register the "Archive Page Template #1" widget area */
		genesis_register_sidebar(
			array(
				'id'            => 'gwat-archive-widget-one',
				'name'          => $gwat_archive_one_widget_title,
				'description'   => $gwat_archive_one_widget_description,
				'before_widget' => '<div id="%1$s" class="gwat-archive gwat-archive-one widget-area">',
				'after_widget'  => '</div>',
			)
		);

		/** Second Widget Area */		
		if ( ! GWAT_NO_SECOND_WIDGET_AREA ) {

			/** Set filter for "Archive Page Template #2" widget title */
			$gwat_archive_two_widget_title = apply_filters( 'gwat_filter_archive_two_widget_title', __( 'Archive Page Template #2', 'genesis-widgetized-archive' ) );

			/** Set filter for "Archive Page Template #2" widget description */
			$gwat_archive_two_widget_description = apply_filters( 'gwat_filter_archive_two_widget_description', __( 'This is the second optional widget area for the Archive Page Template (bundled with the Genesis Framework).', 'genesis-widgetized-archive' ) );

			/** Register the "Archive Page Template #2" widget area */
			genesis_register_sidebar(
				array(
					'id'            => 'gwat-archive-widget-two',
					'name'          => $gwat_archive_two_widget_title,
					'description'   => $gwat_archive_two_widget_description,
					'before_widget' => '<div id="%1$s" class="gwat-archive gwat-archive-two widget-area">',
					'after_widget'  => '</div>',
				)
			);

		}  // end-if constant check for second widget area

		/** Third Widget Area */
		if ( ! GWAT_NO_THIRD_WIDGET_AREA ) {

			/** Set filter for "Archive Page Template #3" widget title */
			$gwat_archive_three_widget_title = apply_filters( 'gwat_filter_archive_three_widget_title', __( 'Archive Page Template #3', 'genesis-widgetized-archive' ) );

			/** Set filter for "Archive Page Template #3" widget description */
			$gwat_archive_three_widget_description = apply_filters( 'gwat_filter_archive_three_widget_description', __( 'This is the third optional widget area for the Archive Page Template (bundled with the Genesis Framework).', 'genesis-widgetized-archive' ) );

			/** Register the "Archive Page Template #3" widget area */
			genesis_register_sidebar(
				array(
					'id'            => 'gwat-archive-widget-three',
					'name'          => $gwat_archive_three_widget_title,
					'description'   => $gwat_archive_three_widget_description,
					'before_widget' => '<div id="%1$s" class="gwat-archive gwat-archive-three widget-area">',
					'after_widget'  => '</div>',
				)
			);

		}  // end-if constant check for third widget area

	}  // end-if Genesis check

}  // end of function ddw_gwat_setup


/**
 * Returns current plugin's header data in a flexible way.
 *
 * @since 1.0.0
 *
 * @uses get_plugins()
 *
 * @param $gwat_plugin_value
 * @param $gwat_plugin_folder
 * @param $gwat_plugin_file
 *
 * @return string Plugin version
 */
function ddw_gwat_plugin_get_data( $gwat_plugin_value ) {

	if ( ! function_exists( 'get_plugins' ) ) {
		require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	}

	$gwat_plugin_folder = get_plugins( '/' . plugin_basename( dirname( __FILE__ ) ) );
	$gwat_plugin_file = basename( ( __FILE__ ) );

	return $gwat_plugin_folder[ $gwat_plugin_file ][ $gwat_plugin_value ];

}  // end of function ddw_gwat_plugin_get_data
